summaryrefslogtreecommitdiff
path: root/.exwm.el
diff options
context:
space:
mode:
Diffstat (limited to '.exwm.el')
-rw-r--r--.exwm.el34
1 files changed, 18 insertions, 16 deletions
diff --git a/.exwm.el b/.exwm.el
index 12b100d..92243e6 100644
--- a/.exwm.el
+++ b/.exwm.el
@@ -1,12 +1,17 @@
;;My EΧWM configuration
;;This files loads before .emacs/init.el when used with emacs-exwm
(defun apollo/exwm-init-hook ()
"Do this upon start."
- (display-battery-mode 0) ;;Change to 1 to display battery
+ (if (string= (system-name) "fsociety") ;; Check if it's my desktop, otherwise display battery
+ (display-battery-mode 0)
+ (display-battery-mode 1))
(setq display-time-day-and-date t)
(display-time-mode 1)
+
+ (exwm-firefox-holyK-mode 1)
;;Launch apps that will run in the background
;; (apollo/run-in-background "blueman-applet")
@@ -32,7 +37,7 @@
;; Set the screen resolution
(require 'exwm-randr)
-(setq exwm-randr-workspace-output-plist '(1 "DP-1" 2 "HDMI-A-0"))
+(setq exwm-randr-workspace-monitor-plist '(0 "DP-1" 2 "HDMI-A-0"))
(add-hook 'exwm-randr-screen-change-hook
(lambda ()
(start-process-shell-command
@@ -76,26 +81,23 @@
;; Keep in mind that changing this list after EXWM initializes has no effect.
(setq exwm-input-global-keys
`(
- ;; Reset to line-mode (C-c C-k switches to char-mode via exwm-input-release-keyboard)
+
([?\s-r] . exwm-reset)
- ;; Move between windows
- ; ([s-up] . windmove-up)
- ; ([s-down] . windmove-down)
- ;; Launch applications via shell command
- ([?\s-&] . (lambda (command)
- (interactive (list (read-shell-command "$ ")))
- (start-process-shell-command command nil command)))
+ ;; ;; Launch applications via shell command
+ ;; ([?\s-&] . (lambda (command)
+ ;; (interactive (list (read-shell-command "$ ")))
+ ;; (start-process-shell-command command nil command)))
;; Switch workspace
([?\s-e] . exwm-workspace-switch)
([?\s-`] . (lambda () (interactive) (exwm-workspace-switch-create 0)))
- ([?\s-1] . (lambda () (interactive) (exwm-workspace-switch-create 1)))
- ([?\s-2] . (lambda () (interactive) (exwm-workspace-switch-create 2)))
- ([?\s-3] . (lambda () (interactive) (exwm-workspace-switch-create 3)))
- ([?\s-4] . (lambda () (interactive) (exwm-workspace-switch-create 4)))
+ ([?\s-2] . (lambda () (interactive) (exwm-workspace-switch-create 1)))
+ ([?\s-3] . (lambda () (interactive) (exwm-workspace-switch-create 2)))
+ ([?\s-4] . (lambda () (interactive) (exwm-workspace-switch-create 3)))
+ ([?\s-5] . (lambda () (interactive) (exwm-workspace-switch-create 4)))
,@(mapcar (lambda (i)
`(,(kbd (format "s-%d" i)) .
@@ -1,12 +1,17 @@
-;;My EΧWM configuration
-;;This files loads before .emacs/init.el when used with emacs-exwm
+;;; My EΧWM configuration
+;; This files loads before .emacs/init.el when used with
+;; GNU Guix emacs-desktop-environment
(defun apollo/exwm-init-hook ()
"Do this upon start."